==> jwinner-base-0.1.7-sources.jar: itez/plat/main/model/base/BasePost.java <==
package itez.plat.main.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BasePost<M extends BasePost<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setSummary(java.lang.String summary) {
		set("summary", summary);
		return (M)this;
	}
	
	public java.lang.String getSummary() {
		return getStr("summary");
	}

	public M setLevelId(java.lang.String levelId) {
		set("levelId", levelId);
		return (M)this;
	}
	
	public java.lang.String getLevelId() {
		return getStr("levelId");
	}

	public M setCoef(java.math.BigDecimal coef) {
		set("coef", coef);
		return (M)this;
	}
	
	public java.math.BigDecimal getCoef() {
		return get("coef");
	}

	public M setRoleIds(java.lang.String roleIds) {
		set("roleIds", roleIds);
		return (M)this;
	}
	
	public java.lang.String getRoleIds() {
		return getStr("roleIds");
	}

	public M setSign(java.lang.String sign) {
		set("sign", sign);
		return (M)this;
	}
	
	public java.lang.String getSign() {
		return getStr("sign");
	}

	public M setTmid(java.lang.String tmid) {
		set("tmid", tmid);
		return (M)this;
	}
	
	public java.lang.String getTmid() {
		return getStr("tmid");
	}

	public M setSort(java.lang.Integer sort) {
		set("sort", sort);
		return (M)this;
	}
	
	public java.lang.Integer getSort() {
		return getInt("sort");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}

==> jwinner-base-0.1.9-sources.jar: itez/plat/main/model/base/BasePost.java <==
package itez.plat.main.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BasePost<M extends BasePost<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setSummary(java.lang.String summary) {
		set("summary", summary);
		return (M)this;
	}
	
	public java.lang.String getSummary() {
		return getStr("summary");
	}

	public M setLevelId(java.lang.String levelId) {
		set("levelId", levelId);
		return (M)this;
	}
	
	public java.lang.String getLevelId() {
		return getStr("levelId");
	}

	public M setCoef(java.math.BigDecimal coef) {
		set("coef", coef);
		return (M)this;
	}
	
	public java.math.BigDecimal getCoef() {
		return get("coef");
	}

	public M setModuleIds(java.lang.String moduleIds) {
		set("moduleIds", moduleIds);
		return (M)this;
	}
	
	public java.lang.String getModuleIds() {
		return getStr("moduleIds");
	}

	public M setRoleIds(java.lang.String roleIds) {
		set("roleIds", roleIds);
		return (M)this;
	}
	
	public java.lang.String getRoleIds() {
		return getStr("roleIds");
	}

	public M setSign(java.lang.String sign) {
		set("sign", sign);
		return (M)this;
	}
	
	public java.lang.String getSign() {
		return getStr("sign");
	}

	public M setSort(java.lang.Integer sort) {
		set("sort", sort);
		return (M)this;
	}
	
	public java.lang.Integer getSort() {
		return getInt("sort");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}
